==> oligo_1.0.2-6.tar.gz: oligo/R/PDInfo-accessors.R <==
setMethod("initialize", "DBPDInfo",
          function(.Object) {
            .Object <- callNextMethod()
            tInfo <- dbGetQuery(db(.Object), "select * from table_info")
            .Object@tableInfo <- tInfo
            .Object
          })

setMethod("manufacturer", "PDInfo",
          function(object) object@manufacturer)

setMethod("genomeBuild", "PDInfo",
          function(object) object@genomebuild)

setMethod("db", "DBPDInfo",
          function(object) object@getdb())

setMethod("geometry", "PDInfo",
          function(object) object@geometry)

setMethod("nrow", "platformDesign", function(x) x@nrow)
setMethod("ncol", "platformDesign", function(x) x@ncol)
## XXX: this should be type(object), but I ran into trouble
## because 'type' is somehow magic.  Didn't have time to
## track it down, so we're using kind for now.
setMethod("kind", "platformDesign", function(object) object@type)


setMethod("listFeatureFields", "AffySNPPDInfo",
          function(object) {
            PM_TABLE <- "pmfeature"
            dbListFields(db(object), PM_TABLE)
          })

setMethod("listFeatureSetFields", "AffySNPPDInfo",
          function(object) {
            FSET_TABLE <- "featureSet"
            dbListFields(db(object), PM_TABLE)
          })

setMethod("nProbes", "AffySNPPDInfo",
          function(object) {
            ## Note: does not include QC probes
            probeTables <- c("mmfeature", "pmfeature")
            sum(subset(object@tableInfo,
                       tbl %in% probeTables, row_count))
          })

setMethod("pmindex", "AffySNPPDInfo",
          function(object) {
            ## might improve by telling RSQLite how
            ## many rows we will fetch?  same for mmindex.
            dbGetQuery(db(object),
                       "select fid from pmfeature")[[1]]
          })

setMethod("mmindex", "AffySNPPDInfo",
          function(object) {
            dbGetQuery(db(object),
                       "select fid from mmfeature")[[1]]
          })

setMethod("pmAllele", "AffySNPPDInfo", function(object)
          dbGetQuery(db(object), "select allele from pmfeature")[[1]])
          
setMethod("kind", "AffySNPPDInfo",
          function(object) {
              "SNP"
          })

## setMethod("featureSetNames", c("AffySNPPDInfo", "missing"),
##           function(object, ids) {
##               sql <- "select man_fsetid from featureSet"
##               dbGetQuery(db(object), sql)[[1]]
##           })
## 
## setMethod("featureSetNames", c("AffySNPPDInfo", "integer"),
##           function(object, ids) {
##             idvals <- paste(as.integer(ids), collapse=",")
##             sql <- paste("SELECT fid, man_fsetid FROM featureSet, %s WHERE",
##                          "fid IN (", idvals, ")",
##                          "AND featureSet.fsetid = %s.fsetid")
##             pmAns <- dbGetQuery(db(object),
##                                 sprintf(sql, "pmfeature", "pmfeature"))
##             mmAns <- dbGetQuery(db(object),
##                                 sprintf(sql, "mmfeature", "mmfeature"))
##             ansIds <- c(pmAns[[1]], mmAns[[1]])
##             idOrd <- match(ansIds, ids)
##             nms <- c(pmAns[[2]], mmAns[[2]])
##             nms[idOrd]
##           })

## setMethod("featureIDs", c("AffySNPPDInfo", "integer"),
##           function(object, ids) {
##               ids
##           })

setMethod("probeNames", "AffySNPPDInfo",
          function(object, subset=NULL) {
            sql <- "select man_fsetid, fid from featureSet, pmfeature where pmfeature.fsetid=featureSet.fsetid"
            tmp <- dbGetQuery(db(object), sql)
            tmp[order(tmp$fid), "man_fsetid"]
          })

## FIXME: this method should be renamed!
## FIXME: this should query the featureSet table (much faster i think)
setMethod("geneNames", "AffySNPPDInfo",
          function(object) {
              unique(probeNames(object))
          })

## pmFeatures <- function(map, featureSetIds) {
##   fsetIds <- paste("'", featureSetIds, "'", sep="", collapse=",")
##   sql <- paste("select man_fsetid, pmfeature.fid, pmfeature.strand,
## pmfeature.allele, pmfeature.x, pmfeature.y from
## pmfeature, featureSet where man_fsetid in (",
##                  fsetIds, ") and featureSet.fsetid = pmfeature.fsetid")
##   dbGetQuery(db(map), sql)
## }

## setMethod("indexFeatureSetName", "AffySNPPDInfo",
##           function(object, featurenames) {
##             ## FIXME: is this what we want?  What about the order?
##             fSetNms <- paste("'", featurenames, "'", sep="", collapse=",")
##             sql <- paste("SELECT fid from featureSet, %s WHERE",
##                          "man_fsetid IN (", fSetNms, ") AND",
##                          "featureSet.fsetid = %s.fsetid")
## 
##             pmIndices <- dbGetQuery(db(object),
##                                     sprintf(sql, "pmfeature"))[[1]]
##             mmIndices <- dbGetQuery(db(object),
##                                     sprintf(sql, "mmfeature"))[[1]]
##             c(pmIndices, mmIndices)
##           })

setMethod("pmSequence", "AffySNPPDInfo",
          function(object){
            sql <- "select seq from sequence, pmfeature where pmfeature.fid=sequence.fid order by pmfeature.fid"
            dbGetQuery(db(object), sql)[[1]]
          })

setMethod("pmPosition", "AffySNPPDInfo",
          function(object){
            sql <- "select offset from sequence, pmfeature where pmfeature.fid=sequence.fid order by pmfeature.fid"
            dbGetQuery(db(object), sql)[[1]]
          })

setMethod("pmFragmentLength", "AffySNPPDInfo",
          function(object){
            sql <- "select fid, fragment_length from featureSet, pmfeature where pmfeature.fsetid=featureSet.fsetid"
            tmp <- dbGetQuery(db(object), sql)
            idx <- order(tmp[["fid"]])
            tmp[idx, "fragment_length"]
          })

setMethod("pmAllele", "AffySNPPDInfo",
          function(object){
            sql <- "select allele from pmfeature order by fid"
            dbGetQuery(db(object), sql)[[1]]
          })

setMethod("pmStrand", "AffySNPPDInfo",
          function(object){
            sql <- "select strand from pmfeature order by fid"
            dbGetQuery(db(object), sql)[[1]]
          })

==> oligo_1.2.2.tar.gz: oligo/R/PDInfo-accessors.R <==
setMethod("initialize", "DBPDInfo",
          function(.Object, ...) {
            .Object <- callNextMethod()
            tInfo <- dbGetQuery(db(.Object), "select * from table_info")
            .Object@tableInfo <- tInfo
            .Object
          })

setMethod("manufacturer", "PDInfo",
          function(object) object@manufacturer)

setMethod("genomeBuild", "PDInfo",
          function(object) object@genomebuild)

setMethod("db", signature(object="DBPDInfo"),
          function(object) object@getdb())

setMethod("geometry", "PDInfo",
          function(object) object@geometry)

setMethod("nrow", "platformDesign", function(x) x@nrow)
setMethod("ncol", "platformDesign", function(x) x@ncol)
## XXX: this should be type(object), but I ran into trouble
## because 'type' is somehow magic.  Didn't have time to
## track it down, so we're using kind for now.
setMethod("kind", "platformDesign", function(object) object@type)


setMethod("listFeatureFields", "AffySNPPDInfo",
          function(object) {
            PM_TABLE <- "pmfeature"
            dbListFields(db(object), PM_TABLE)
          })

setMethod("listFeatureSetFields", "AffySNPPDInfo",
          function(object) {
            FSET_TABLE <- "featureSet"
            dbListFields(db(object), PM_TABLE)
          })

setMethod("nProbes", "AffySNPPDInfo",
          function(object) {
            ## Note: does not include QC probes
            probeTables <- c("mmfeature", "pmfeature")
            sum(subset(object@tableInfo,
                       tbl %in% probeTables, row_count))
          })

setMethod("pmindex", "AffySNPPDInfo",
          function(object) {
            ## might improve by telling RSQLite how
            ## many rows we will fetch?  same for mmindex.
            dbGetQuery(db(object),
                       "select fid from pmfeature")[[1]]
          })

setMethod("mmindex", "AffySNPPDInfo",
          function(object) {
            dbGetQuery(db(object),
                       "select fid from mmfeature")[[1]]
          })

setMethod("kind", "AffySNPPDInfo",
          function(object) {
              "SNP"
          })

setMethod("kind", "AffySNPCNVPDInfo",
          function(object) {
              "SNPCNV"
          })

## setMethod("featureSetNames", c("AffySNPPDInfo", "missing"),
##           function(object, ids) {
##               sql <- "select man_fsetid from featureSet"
##               dbGetQuery(db(object), sql)[[1]]
##           })
## 
## setMethod("featureSetNames", c("AffySNPPDInfo", "integer"),
##           function(object, ids) {
##             idvals <- paste(as.integer(ids), collapse=",")
##             sql <- paste("SELECT fid, man_fsetid FROM featureSet, %s WHERE",
##                          "fid IN (", idvals, ")",
##                          "AND featureSet.fsetid = %s.fsetid")
##             pmAns <- dbGetQuery(db(object),
##                                 sprintf(sql, "pmfeature", "pmfeature"))
##             mmAns <- dbGetQuery(db(object),
##                                 sprintf(sql, "mmfeature", "mmfeature"))
##             ansIds <- c(pmAns[[1]], mmAns[[1]])
##             idOrd <- match(ansIds, ids)
##             nms <- c(pmAns[[2]], mmAns[[2]])
##             nms[idOrd]
##           })

## setMethod("featureIDs", c("AffySNPPDInfo", "integer"),
##           function(object, ids) {
##               ids
##           })

setMethod("probeNames", "AffySNPPDInfo",
          function(object, subset=NULL) {
            sql <- "select man_fsetid, fid from featureSet, pmfeature where pmfeature.fsetid=featureSet.fsetid"
            tmp <- dbGetQuery(db(object), sql)
            tmp[order(tmp$fid), "man_fsetid"]
          })

## FIXME: this method should be renamed!
## FIXME: this should query the featureSet table (much faster i think)
setMethod("geneNames", "AffySNPPDInfo",
          function(object) {
              unique(probeNames(object))
          })

## pmFeatures <- function(map, featureSetIds) {
##   fsetIds <- paste("'", featureSetIds, "'", sep="", collapse=",")
##   sql <- paste("select man_fsetid, pmfeature.fid, pmfeature.strand,
## pmfeature.allele, pmfeature.x, pmfeature.y from
## pmfeature, featureSet where man_fsetid in (",
##                  fsetIds, ") and featureSet.fsetid = pmfeature.fsetid")
##   dbGetQuery(db(map), sql)
## }

## setMethod("indexFeatureSetName", "AffySNPPDInfo",
##           function(object, featurenames) {
##             ## FIXME: is this what we want?  What about the order?
##             fSetNms <- paste("'", featurenames, "'", sep="", collapse=",")
##             sql <- paste("SELECT fid from featureSet, %s WHERE",
##                          "man_fsetid IN (", fSetNms, ") AND",
##                          "featureSet.fsetid = %s.fsetid")
## 
##             pmIndices <- dbGetQuery(db(object),
##                                     sprintf(sql, "pmfeature"))[[1]]
##             mmIndices <- dbGetQuery(db(object),
##                                     sprintf(sql, "mmfeature"))[[1]]
##             c(pmIndices, mmIndices)
##           })

setMethod("pmSequence", "AffySNPPDInfo",
          function(object){
            sql <- "select seq from sequence, pmfeature where pmfeature.fid=sequence.fid order by pmfeature.fid"
            dbGetQuery(db(object), sql)[[1]]
          })

setMethod("pmPosition", "AffySNPPDInfo",
          function(object){
            sql <- "select offset from sequence, pmfeature where pmfeature.fid=sequence.fid order by pmfeature.fid"
            dbGetQuery(db(object), sql)[[1]]
          })

setMethod("pmFragmentLength", "AffySNPPDInfo",
          function(object){
            sql <- "select fid, fragment_length from featureSet, pmfeature where pmfeature.fsetid=featureSet.fsetid"
            tmp <- dbGetQuery(db(object), sql)
            idx <- order(tmp[["fid"]])
            tmp[idx, "fragment_length"]
          })

setMethod("pmAllele", "AffySNPPDInfo",
          function(object){
            sql <- "select allele from pmfeature order by fid"
            dbGetQuery(db(object), sql)[[1]]
          })

setMethod("pmStrand", "AffySNPPDInfo",
          function(object){
            sql <- "select strand from pmfeature order by fid"
            dbGetQuery(db(object), sql)[[1]]
          })
